@@ -115,7 +115,7 @@ class Scene(NodeMixin):
     def col(self) -> str:
         pre = self.act or ""
         if pre:
-            pieces = self.act.split("-")
+            pieces = pre.split("-")
             if len(pieces) == 2:
                 pre = f"{pieces[1].upper()}: "
             else:
@@ -527,7 +527,7 @@ ResolvedNodeT = Union[
     Speech,
     Intermission,
 ]
-SpeechNodeT = Union[Dialogue, Action, Direction]
+SpeechNodeT = Union[Dialogue, Action, Direction, Entrance, Exit]
 SpeechBodyT = Tuple[SpeechNodeT, ...]
 ActNodeT = Union[Scene, Intermission, Epilogue, Prologue]
 ActBodyT = Tuple[ActNodeT, ...]
